@@ -8,9 +8,10 @@
 
 #include <limits.h>
 
+#include "videolink.hpp"
 #include "wchar_t_short.h"
 #include <gtkmozembed_internal.h>
-#if MOZ_VERSION_MAJOR == 1 && MOZ_VERSION_MINOR == 9
+#if MOZ_VERSION_GE(1,9,0)
 #include <gtkmozembed_glue.cpp>
 #endif
 #include "wchar_t_default.h"
@@ -530,14 +531,20 @@ Glib::ObjectBase * browser_widget::wrap_new(GObject * gobject)
 
 browser_widget::initialiser::initialiser()
 {
-#if MOZ_VERSION_MAJOR == 1 && MOZ_VERSION_MINOR == 9
+#if MOZ_VERSION_GE(1,9,0)
     static const GREVersionRange gre_versions = {
-#if MOZ_VERSION_MICRO == 0
+#if MOZ_VERSION_EQ(1,9,0)
 	"1.9a", PR_TRUE,
 	"1.9.1", PR_FALSE
-#elif MOZ_VERSION_MICRO == 1
+#elif MOZ_VERSION_EQ(1,9,1)
 	"1.9.1", PR_TRUE,
 	"1.9.2", PR_FALSE
+#elif MOZ_VERSION_EQ(2,0,-1) || MOZ_VERSION_EQ(2,0,0)
+	"2.0b", PR_TRUE,
+	"2.0.1", PR_FALSE
+#elif MOZ_VERSION_EQ(2,0,1)
+	"2.0.1", PR_TRUE,
+	"2.0.2", PR_FALSE
 #else
 #error "version is unsupported, but you could try continuing the pattern above"
 #endif
@@ -567,7 +574,7 @@ browser_widget::initialiser::~initialiser()
 {
     gtk_moz_embed_pop_startup();
 
-#if MOZ_VERSION_MAJOR == 1 && MOZ_VERSION_MINOR == 9
+#if MOZ_VERSION_GE(1,9,0)
     XPCOMGlueShutdown();
 #endif
 }
