@@ -360,8 +360,9 @@ void dvd_generator::generate(const std::string & output_dir) const
 	const bool have_real_menus =
 	    titleset_num * dvdauthor_anonymous_menus_max < menus_.size();
 
-	file << "  <" << outer_element_name << ">\n"
-	     << "    <menus>\n";
+	file << "  <" << outer_element_name << ">\n" <<
+	     "    <menus>\n"
+	     "      <video format='" << frame_params_.common_name << "'/>\n";
 
 	const unsigned menu_begin = titleset_num * dvdauthor_anonymous_menus_max;
 	const unsigned menu_end =
@@ -606,6 +607,7 @@ void dvd_generator::generate(const std::string & output_dir) const
 	{
 	    file <<
 		"    <titles>\n"
+		"      <video format='" << frame_params_.common_name << "'/>\n"
 		"      <pgc>\n";
 
 	    file << "        <pre>\n";
